==> zio-aws-qldb_3-5.17.124.1-sources.jar: zio/aws/qldb/model/UpdateLedgerResponse.scala <==
package zio.aws.qldb.model
import zio.ZIO
import zio.aws.qldb.model.primitives.{
  DeletionProtection,
  Timestamp,
  Arn,
  LedgerName
}
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters.*
final case class UpdateLedgerResponse(
    name: Option[LedgerName] = None,
    arn: Option[Arn] = None,
    state: Option[zio.aws.qldb.model.LedgerState] = None,
    creationDateTime: Option[Timestamp] = None,
    deletionProtection: Option[DeletionProtection] = None,
    encryptionDescription: Option[
      zio.aws.qldb.model.LedgerEncryptionDescription
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.qldb.model.UpdateLedgerResponse = {
    import UpdateLedgerResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.qldb.model.UpdateLedgerResponse
      .builder()
      .optionallyWith(
        name.map(value => LedgerName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(arn.map(value => Arn.unwrap(value): java.lang.String))(
        _.arn
      )
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .optionallyWith(
        creationDateTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.creationDateTime)
      .optionallyWith(
        deletionProtection.map(value =>
          DeletionProtection.unwrap(value): java.lang.Boolean
        )
      )(_.deletionProtection)
      .optionallyWith(
        encryptionDescription.map(value => value.buildAwsValue())
      )(_.encryptionDescription)
      .build()
  }
  def asReadOnly: zio.aws.qldb.model.UpdateLedgerResponse.ReadOnly =
    zio.aws.qldb.model.UpdateLedgerResponse.wrap(buildAwsValue())
}
object UpdateLedgerResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.qldb.model.UpdateLedgerResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.qldb.model.UpdateLedgerResponse =
      zio.aws.qldb.model.UpdateLedgerResponse(
        name.map(value => value),
        arn.map(value => value),
        state.map(value => value),
        creationDateTime.map(value => value),
        deletionProtection.map(value => value),
        encryptionDescription.map(value => value.asEditable)
      )
    def name: Option[LedgerName]
    def arn: Option[Arn]
    def state: Option[zio.aws.qldb.model.LedgerState]
    def creationDateTime: Option[Timestamp]
    def deletionProtection: Option[DeletionProtection]
    def encryptionDescription
        : Option[zio.aws.qldb.model.LedgerEncryptionDescription.ReadOnly]
    def getName: ZIO[Any, AwsError, LedgerName] =
      AwsError.unwrapOptionField("name", name)
    def getArn: ZIO[Any, AwsError, Arn] = AwsError.unwrapOptionField("arn", arn)
    def getState: ZIO[Any, AwsError, zio.aws.qldb.model.LedgerState] =
      AwsError.unwrapOptionField("state", state)
    def getCreationDateTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("creationDateTime", creationDateTime)
    def getDeletionProtection: ZIO[Any, AwsError, DeletionProtection] =
      AwsError.unwrapOptionField("deletionProtection", deletionProtection)
    def getEncryptionDescription: ZIO[
      Any,
      AwsError,
      zio.aws.qldb.model.LedgerEncryptionDescription.ReadOnly
    ] =
      AwsError.unwrapOptionField("encryptionDescription", encryptionDescription)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.qldb.model.UpdateLedgerResponse
  ) extends zio.aws.qldb.model.UpdateLedgerResponse.ReadOnly {
    override val name: Option[LedgerName] = scala
      .Option(impl.name())
      .map(value => zio.aws.qldb.model.primitives.LedgerName(value))
    override val arn: Option[Arn] = scala
      .Option(impl.arn())
      .map(value => zio.aws.qldb.model.primitives.Arn(value))
    override val state: Option[zio.aws.qldb.model.LedgerState] = scala
      .Option(impl.state())
      .map(value => zio.aws.qldb.model.LedgerState.wrap(value))
    override val creationDateTime: Option[Timestamp] = scala
      .Option(impl.creationDateTime())
      .map(value => zio.aws.qldb.model.primitives.Timestamp(value))
    override val deletionProtection: Option[DeletionProtection] = scala
      .Option(impl.deletionProtection())
      .map(value => zio.aws.qldb.model.primitives.DeletionProtection(value))
    override val encryptionDescription
        : Option[zio.aws.qldb.model.LedgerEncryptionDescription.ReadOnly] =
      scala
        .Option(impl.encryptionDescription())
        .map(value =>
          zio.aws.qldb.model.LedgerEncryptionDescription.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.qldb.model.UpdateLedgerResponse
  ): zio.aws.qldb.model.UpdateLedgerResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-qldb_3-5.19.8.2-sources.jar: zio/aws/qldb/model/UpdateLedgerResponse.scala <==
package zio.aws.qldb.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.qldb.model.primitives.{
  DeletionProtection,
  Timestamp,
  Arn,
  LedgerName
}
import zio.ZIO
import scala.jdk.CollectionConverters.*
final case class UpdateLedgerResponse(
    name: Optional[LedgerName] = Optional.Absent,
    arn: Optional[Arn] = Optional.Absent,
    state: Optional[zio.aws.qldb.model.LedgerState] = Optional.Absent,
    creationDateTime: Optional[Timestamp] = Optional.Absent,
    deletionProtection: Optional[DeletionProtection] = Optional.Absent,
    encryptionDescription: Optional[
      zio.aws.qldb.model.LedgerEncryptionDescription
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.qldb.model.UpdateLedgerResponse = {
    import UpdateLedgerResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.qldb.model.UpdateLedgerResponse
      .builder()
      .optionallyWith(
        name.map(value => LedgerName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(arn.map(value => Arn.unwrap(value): java.lang.String))(
        _.arn
      )
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .optionallyWith(
        creationDateTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.creationDateTime)
      .optionallyWith(
        deletionProtection.map(value =>
          DeletionProtection.unwrap(value): java.lang.Boolean
        )
      )(_.deletionProtection)
      .optionallyWith(
        encryptionDescription.map(value => value.buildAwsValue())
      )(_.encryptionDescription)
      .build()
  }
  def asReadOnly: zio.aws.qldb.model.UpdateLedgerResponse.ReadOnly =
    zio.aws.qldb.model.UpdateLedgerResponse.wrap(buildAwsValue())
}
object UpdateLedgerResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.qldb.model.UpdateLedgerResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.qldb.model.UpdateLedgerResponse =
      zio.aws.qldb.model.UpdateLedgerResponse(
        name.map(value => value),
        arn.map(value => value),
        state.map(value => value),
        creationDateTime.map(value => value),
        deletionProtection.map(value => value),
        encryptionDescription.map(value => value.asEditable)
      )
    def name: Optional[LedgerName]
    def arn: Optional[Arn]
    def state: Optional[zio.aws.qldb.model.LedgerState]
    def creationDateTime: Optional[Timestamp]
    def deletionProtection: Optional[DeletionProtection]
    def encryptionDescription
        : Optional[zio.aws.qldb.model.LedgerEncryptionDescription.ReadOnly]
    def getName: ZIO[Any, AwsError, LedgerName] =
      AwsError.unwrapOptionField("name", name)
    def getArn: ZIO[Any, AwsError, Arn] = AwsError.unwrapOptionField("arn", arn)
    def getState: ZIO[Any, AwsError, zio.aws.qldb.model.LedgerState] =
      AwsError.unwrapOptionField("state", state)
    def getCreationDateTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("creationDateTime", creationDateTime)
    def getDeletionProtection: ZIO[Any, AwsError, DeletionProtection] =
      AwsError.unwrapOptionField("deletionProtection", deletionProtection)
    def getEncryptionDescription: ZIO[
      Any,
      AwsError,
      zio.aws.qldb.model.LedgerEncryptionDescription.ReadOnly
    ] =
      AwsError.unwrapOptionField("encryptionDescription", encryptionDescription)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.qldb.model.UpdateLedgerResponse
  ) extends zio.aws.qldb.model.UpdateLedgerResponse.ReadOnly {
    override val name: Optional[LedgerName] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.qldb.model.primitives.LedgerName(value))
    override val arn: Optional[Arn] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value => zio.aws.qldb.model.primitives.Arn(value))
    override val state: Optional[zio.aws.qldb.model.LedgerState] =
      zio.aws.core.internal
        .optionalFromNullable(impl.state())
        .map(value => zio.aws.qldb.model.LedgerState.wrap(value))
    override val creationDateTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.creationDateTime())
      .map(value => zio.aws.qldb.model.primitives.Timestamp(value))
    override val deletionProtection: Optional[DeletionProtection] =
      zio.aws.core.internal
        .optionalFromNullable(impl.deletionProtection())
        .map(value => zio.aws.qldb.model.primitives.DeletionProtection(value))
    override val encryptionDescription
        : Optional[zio.aws.qldb.model.LedgerEncryptionDescription.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.encryptionDescription())
        .map(value =>
          zio.aws.qldb.model.LedgerEncryptionDescription.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.qldb.model.UpdateLedgerResponse
  ): zio.aws.qldb.model.UpdateLedgerResponse.ReadOnly = new Wrapper(impl)
}
